## dbt-adapters 1.14.1 - March 04, 2025

### Fixes

- Fix incremental delete+insert SQL ([#150,](https://github.com/dbt-labs/dbt-adapters/issues/150,), [#364](https://github.com/dbt-labs/dbt-adapters/issues/364))

### Contributors
- [@ataft,](https://github.com/ataft,) ([#150,](https://github.com/dbt-labs/dbt-adapters/issues/150,), [#364](https://github.com/dbt-labs/dbt-adapters/issues/364))
